@@ -2,6 +2,6 @@ setnv <- function( nvtxt = "nvsapdefault" ) {
 
   nvinternal        <- eval( parse( text = nvtxt ) ) 
   nvinternal$nvname <- nvtxt
-  assign( "nv", nvinternal, envir = vfenv )
+  assign( "nv", nvinternal, envir = visualFields::vfenv )
 
 }
