@@ -15,7 +15,7 @@ vfiperc <- function( vals, percentiles = c( 0.5, 1, 2, 5, 95 ),
   }
 
 # get settings for the pattern of test locations
-  locini   <- vfsettings$locini
+  locini   <- visualFields::vfsettings$locini
   texteval <- paste( "vfsettings$", vals$tpattern[1], sep = "" )
   settings <- eval( parse( text = texteval ) )
 # get how many locations we need to look at
